<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:b1e="urn:com.sap.b1i.sim:b1event" xmlns:b1ie="urn:com.sap.b1i.sim:b1ievent" xmlns:b1im="urn:com.sap.b1i.sim:b1imessage" xmlns:bfa="urn:com.sap.b1i.bizprocessor:bizatoms" xmlns:jdbc="urn:com.sap.b1i.adapter:jdbcadapter" xmlns:js="com.sap.b1i.bpc_tools.Javascript" xmlns:rfc="urn:sap-com:document:sap:rfc:functions" xmlns:sim="urn:com.sap.b1i.sim:entity" xmlns:uplt="urn:com.sap.b1i.xcellerator:upltdoc" xmlns:utils2="com.sap.b1i.bpc_tools.Utilities" xmlns:vpf="urn:com.sap.b1i.vplatform:entity" xmlns:xci="urn:com.sap.b1i.xcellerator:intdoc" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" bfa:force="" vpf:force="" jdbc:force="" rfc:force="" b1ie:force="" b1e:force="" xci:force="" sim:force="" utils2:force="" b1im:force="" uplt:force="" js:force="">
  <xsl:output method="xml" encoding="UTF-8" indent="yes"/>
  <xsl:param name="atom"/>
  <xsl:param name="sessionid"/>
  <xsl:variable name="msg" select="/vpf:Msg/vpf:Body/vpf:Payload[./@Role='S']"/>
  <xsl:variable name="vpSender" select="/vpf:Msg/vpf:Header/vpf:Sender/@Id"/>
  <xsl:variable name="vpObject" select="/vpf:Msg/vpf:Header/vpf:Sender/@ObjId"/>
  <xsl:variable name="vpReceiver" select="/vpf:Msg/vpf:Header/vpf:ReceiverList/vpf:Receiver[./@handover='P']/@Id"/>
  <xsl:variable name="vpCOBIAppVersion" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIAppVersion']/@value"/>
  <xsl:variable name="vpCOBIDeviceId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIDeviceId']/@value"/>
  <xsl:variable name="vpCOBIProfile" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIProfile']/@value"/>
  <xsl:variable name="vpCOBISysId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBISysId']/@value"/>
  <xsl:variable name="vpCOBIUserId" select="/vpf:Msg/vpf:Header/vpf:Variables/vpf:var[./@id='COBIUserId']/@value"/>
  <xsl:variable name="vpCOBIFiles" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIFiles']/@value"/>
  <xsl:variable name="vpCOBILogs" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBILogs']/@value"/>
  <xsl:variable name="vpCOBIEnablePDNDraft" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIEnablePDNDraft']/@value"/>
  <xsl:variable name="vpCOBIRemPrtPath" select="/vpf:Msg/vpf:Header/vpf:Properties/vpf:prop[./@id='COBIRemPrtPath']/@value"/>
  <xsl:template match="/">
    <xsl:variable name="vptsDoc" select="document('/com.sap.b1i.internal/xml/timestamp')"/>
    <xsl:variable name="vpts" select="concat($vptsDoc/*/@year,'/',$vptsDoc/*/@month,'/',$vptsDoc/*/@date,' ',$vptsDoc/*/@hour,':',$vptsDoc/*/@minute,':',$vptsDoc/*/@second)"/>
    <vpf:Msg>
      <xsl:copy-of select="/vpf:Msg/@*"/>
      <xsl:copy-of select="/vpf:Msg/vpf:Header"/>
      <vpf:Body>
        <xsl:copy-of select="/vpf:Msg/vpf:Body/*"/>
        <vpf:Payload Role="X" id="{$atom}" ts="{$vpts}">
          <xsl:call-template name="transform"/>
        </vpf:Payload>
      </vpf:Body>
    </vpf:Msg>
  </xsl:template>
  <xsl:template name="transform">
    <xsl:variable name="exec" select="$msg/cobiwms/body/execution"/>
    <Envelope>
      <Header>
        <xsl:if test="$exec/id">
          <Action autoCommit="true" DIServiceName="GeneralService" update="update" get="getByParams" throwException="false">update</Action>
        </xsl:if>
        <xsl:if test="not($exec/id)">
          <Action autoCommit="true" DIServiceName="GeneralService" add="add" get="getByParams" throwException="false">add</Action>
        </xsl:if>
      </Header>
      <Body>
        <BS ServiceCode="CWMS_MTPN_EXECUTION">
          <InsertOrUpdate>
            <CWMS_MTPN_EXECUTION>
              <xsl:if test="$exec/id">
                <DocEntry>
                  <xsl:value-of select="$exec/id"/>
                </DocEntry>
              </xsl:if>
              <U_Task>
                <xsl:value-of select="$exec/task/code"/>
              </U_Task>
              <U_Date>
                <xsl:value-of select="$exec/date"/>
              </U_Date>
              <U_Time>
                <xsl:value-of select="$exec/time"/>
              </U_Time>
              <U_Employee>
                <xsl:value-of select="$exec/employee"/>
              </U_Employee>
              <U_Employee2>
                <xsl:value-of select="$exec/employee2"/>
              </U_Employee2>
              <Remark>
                <xsl:value-of select="$exec/remarks"/>
              </Remark>
              <xsl:if test="$exec/lines/line">
                <CWMS_MTPN_EXECLINESCollection>
                  <xsl:for-each select="$exec/lines/line">
                    <CWMS_MTPN_EXECLINES>
                      <U_Name>
                        <xsl:value-of select="name"/>
                      </U_Name>
                      <U_Value>
                        <xsl:value-of select="value"/>
                      </U_Value>
                    </CWMS_MTPN_EXECLINES>
                  </xsl:for-each>
                </CWMS_MTPN_EXECLINESCollection>
              </xsl:if>
            </CWMS_MTPN_EXECUTION>
          </InsertOrUpdate>
        </BS>
      </Body>
    </Envelope>
  </xsl:template>
</xsl:stylesheet>
